@@ -39,7 +39,8 @@ a0 <- Sys.time()
     Y <- tamobj$Y
 	YSD <- tamobj$YSD
     nitems <- tamobj$nitems
-
+	snodes <- tamobj$control$snodes 
+	
     beta <- tamobj$beta
     variance <- tamobj$variance
     nstud <- tamobj$nstud
@@ -122,10 +123,10 @@ a0 <- Sys.time()
 					}
 # cat("calc prob") ; a1 <- Sys.time(); print(a1-a0) ; a0 <- a1			
 
-
 		# calculate student's prior distribution    	
 		gwt <- stud_prior.v2( theta=theta , Y=Y , beta=beta , variance=variance , nstud=nstud , 
-                          nnodes=nnodes , ndim=ndim , YSD=YSD , unidim_simplify=FALSE)
+                          nnodes=nnodes , ndim=ndim , YSD=YSD , unidim_simplify=FALSE,
+						  snodes = snodes )
 # cat("stud prior") ; a1 <- Sys.time(); print(a1-a0) ; a0 <- a1							  
    
    
